==> nomachine-8.7.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXServices.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXServices;no warnings;my (%sessionParameterForService);(
$sessionParameterForService{"\x61\x75\x64\x69\x6f"}="\x6d\x65\x64\x69\x61");(
$sessionParameterForService{"\x6d\x69\x63\x72\x6f\x70\x68\x6f\x6e\x65"}=
"\x6d\x65\x64\x69\x61");($sessionParameterForService{
"\x53\x4d\x42\x46\x53\x2d\x73\x68\x61\x72\x69\x6e\x67"}="\x73\x61\x6d\x62\x61");
($sessionParameterForService{
"\x70\x72\x69\x6e\x74\x65\x72\x5f\x69\x70\x70\x5f\x73\x68\x61\x72\x69\x6e\x67"}=
"\x63\x75\x70\x73");($sessionParameterForService{
"\x70\x72\x69\x6e\x74\x65\x72\x5f\x73\x6d\x62\x5f\x73\x68\x61\x72\x69\x6e\x67"}=
"\x63\x75\x70\x73");($sessionParameterForService{
"\x70\x72\x69\x6e\x74\x65\x72\x5f\x76\x69\x72\x74\x75\x61\x6c\x5f\x73\x68\x61\x72\x69\x6e\x67"
}="\x63\x75\x70\x73");my (%servicesForSessionParameter);(
$servicesForSessionParameter{"\x6d\x65\x64\x69\x61"}=
"\x61\x75\x64\x69\x6f\x2c\x6d\x69\x63\x72\x6f\x70\x68\x6f\x6e\x65\x2c");(
$servicesForSessionParameter{"\x73\x61\x6d\x62\x61"}=
"\x53\x4d\x42\x46\x53\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c");(
$servicesForSessionParameter{"\x63\x75\x70\x73"}=
"\x70\x72\x69\x6e\x74\x65\x72\x5f\x69\x70\x70\x5f\x73\x68\x61\x72\x69\x6e\x67\x2c\x70\x72\x69\x6e\x74\x65\x72\x5f\x73\x6d\x62\x5f\x73\x68\x61\x72\x69\x6e\x67\x2c\x70\x72\x69\x6e\x74\x65\x72\x5f\x76\x69\x72\x74\x75\x61\x6c\x5f\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST=$servicesForSessionParameter{
"\x6d\x65\x64\x69\x61"});($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x70\x72\x69\x6e\x74\x65\x72\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x70\x72\x69\x6e\x74\x65\x72\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x75\x73\x62\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x75\x73\x62\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x64\x69\x73\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x64\x69\x73\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x6e\x65\x74\x77\x6f\x72\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x6e\x65\x74\x77\x6f\x72\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x63\x6c\x69\x65\x6e\x74\x2d\x73\x6d\x61\x72\x74\x63\x61\x72\x64\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x66\x69\x6c\x65\x2d\x74\x72\x61\x6e\x73\x66\x65\x72\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x66\x69\x6c\x65\x2d\x74\x72\x61\x6e\x73\x66\x65\x72\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x73\x73\x69\x6f\x6e\x2d\x72\x65\x63\x6f\x72\x64\x69\x6e\x67\x2c\x6c\x6f\x63\x61\x6c\x2d\x72\x65\x63\x6f\x72\x64\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x69\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x2d\x6d\x6f\x64\x65");(
$GLOBAL::SERVICES_NOT_ALLOWED_FOR_GDS=
"\x73\x65\x72\x76\x65\x72\x2d\x70\x72\x69\x6e\x74\x65\x72\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x70\x72\x69\x6e\x74\x65\x72\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x73\x65\x72\x76\x65\x72\x2d\x75\x73\x62\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::SERVICES_NOT_ALLOWED_FOR_GDS.=
"\x63\x6c\x69\x65\x6e\x74\x2d\x75\x73\x62\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x73\x65\x72\x76\x65\x72\x2d\x64\x69\x73\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x64\x69\x73\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::SERVICES_NOT_ALLOWED_FOR_GDS.=
"\x73\x65\x72\x76\x65\x72\x2d\x6e\x65\x74\x77\x6f\x72\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x6e\x65\x74\x77\x6f\x72\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x73\x6d\x61\x72\x74\x63\x61\x72\x64\x2d\x73\x68\x61\x72\x69\x6e\x67"
);sub getAllPosibleServicesList{return ($GLOBAL::ALL_POSSIBLE_SERVICES_LIST);}
sub getSessionParameterForService{(my $service=shift (@_));return (
$sessionParameterForService{$service});}sub getServicesForSessionParameter{(my $sessionParameter
=shift (@_));(my (@services)=split ( /,/ ,$servicesForSessionParameter{
$sessionParameter},(0x14ff+ 1707-0x1baa)));return (@services);}sub 
getAllPosibleSessionParameters{(my (@sessionParameters)=keys (
%servicesForSessionParameter));return (@sessionParameters);}return (
(0x0302+ 1383-0x0868));

==> nomachine-8.8.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXServices.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXServices;no warnings;my (%sessionParameterForService);(
$sessionParameterForService{"\x61\x75\x64\x69\x6f"}="\x6d\x65\x64\x69\x61");(
$sessionParameterForService{"\x6d\x69\x63\x72\x6f\x70\x68\x6f\x6e\x65"}=
"\x6d\x65\x64\x69\x61");($sessionParameterForService{
"\x53\x4d\x42\x46\x53\x2d\x73\x68\x61\x72\x69\x6e\x67"}="\x73\x61\x6d\x62\x61");
($sessionParameterForService{
"\x70\x72\x69\x6e\x74\x65\x72\x5f\x69\x70\x70\x5f\x73\x68\x61\x72\x69\x6e\x67"}=
"\x63\x75\x70\x73");($sessionParameterForService{
"\x70\x72\x69\x6e\x74\x65\x72\x5f\x73\x6d\x62\x5f\x73\x68\x61\x72\x69\x6e\x67"}=
"\x63\x75\x70\x73");($sessionParameterForService{
"\x70\x72\x69\x6e\x74\x65\x72\x5f\x76\x69\x72\x74\x75\x61\x6c\x5f\x73\x68\x61\x72\x69\x6e\x67"
}="\x63\x75\x70\x73");my (%servicesForSessionParameter);(
$servicesForSessionParameter{"\x6d\x65\x64\x69\x61"}=
"\x61\x75\x64\x69\x6f\x2c\x6d\x69\x63\x72\x6f\x70\x68\x6f\x6e\x65\x2c");(
$servicesForSessionParameter{"\x73\x61\x6d\x62\x61"}=
"\x53\x4d\x42\x46\x53\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c");(
$servicesForSessionParameter{"\x63\x75\x70\x73"}=
"\x70\x72\x69\x6e\x74\x65\x72\x5f\x69\x70\x70\x5f\x73\x68\x61\x72\x69\x6e\x67\x2c\x70\x72\x69\x6e\x74\x65\x72\x5f\x73\x6d\x62\x5f\x73\x68\x61\x72\x69\x6e\x67\x2c\x70\x72\x69\x6e\x74\x65\x72\x5f\x76\x69\x72\x74\x75\x61\x6c\x5f\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST=$servicesForSessionParameter{
"\x6d\x65\x64\x69\x61"});($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x70\x72\x69\x6e\x74\x65\x72\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x70\x72\x69\x6e\x74\x65\x72\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x75\x73\x62\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x75\x73\x62\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x64\x69\x73\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x64\x69\x73\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x6e\x65\x74\x77\x6f\x72\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x6e\x65\x74\x77\x6f\x72\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x63\x6c\x69\x65\x6e\x74\x2d\x73\x6d\x61\x72\x74\x63\x61\x72\x64\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x72\x76\x65\x72\x2d\x66\x69\x6c\x65\x2d\x74\x72\x61\x6e\x73\x66\x65\x72\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x66\x69\x6c\x65\x2d\x74\x72\x61\x6e\x73\x66\x65\x72\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x73\x65\x73\x73\x69\x6f\x6e\x2d\x72\x65\x63\x6f\x72\x64\x69\x6e\x67\x2c\x6c\x6f\x63\x61\x6c\x2d\x72\x65\x63\x6f\x72\x64\x69\x6e\x67\x2c"
);($GLOBAL::ALL_POSSIBLE_SERVICES_LIST.=
"\x69\x6e\x74\x65\x72\x61\x63\x74\x69\x76\x65\x2d\x6d\x6f\x64\x65");(
$GLOBAL::SERVICES_NOT_ALLOWED_FOR_GDS=
"\x73\x65\x72\x76\x65\x72\x2d\x70\x72\x69\x6e\x74\x65\x72\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x70\x72\x69\x6e\x74\x65\x72\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x73\x65\x72\x76\x65\x72\x2d\x75\x73\x62\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::SERVICES_NOT_ALLOWED_FOR_GDS.=
"\x63\x6c\x69\x65\x6e\x74\x2d\x75\x73\x62\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x73\x65\x72\x76\x65\x72\x2d\x64\x69\x73\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x64\x69\x73\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c"
);($GLOBAL::SERVICES_NOT_ALLOWED_FOR_GDS.=
"\x73\x65\x72\x76\x65\x72\x2d\x6e\x65\x74\x77\x6f\x72\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x6e\x65\x74\x77\x6f\x72\x6b\x2d\x73\x68\x61\x72\x69\x6e\x67\x2c\x63\x6c\x69\x65\x6e\x74\x2d\x73\x6d\x61\x72\x74\x63\x61\x72\x64\x2d\x73\x68\x61\x72\x69\x6e\x67"
);sub getAllPosibleServicesList{return ($GLOBAL::ALL_POSSIBLE_SERVICES_LIST);}
sub getSessionParameterForService{(my $service=shift (@_));return (
$sessionParameterForService{$service});}sub getServicesForSessionParameter{(my $sessionParameter
=shift (@_));(my (@services)=split ( /,/ ,$servicesForSessionParameter{
$sessionParameter},(0x1d4c+ 1593-0x2385)));return (@services);}sub 
getAllPosibleSessionParameters{(my (@sessionParameters)=keys (
%servicesForSessionParameter));return (@sessionParameters);}return (
(0x0f68+ 4075-0x1f52));
